;;;                 -*- Mode: Lisp; Package: BOOMS-APP -*-                  ;;;
;;; ----------------------------------------------------------------------- ;;;
;;; File:         constant.lsp                                              ;;;
;;; Description:  BOOMS application constants                               ;;;
;;; Author:       Eli Barzilay - eli@cs.bgu.ac.il                           ;;;
;;; Idea by:      Omri Weisman - omri@cs.bgu.ac.il                          ;;;
;;;               Cohavit Taboch  - taboch@cs.bgu.ac.il                     ;;;
;;; Date:         24-12-96                                                  ;;;
;;; Package:      BOOMS-APP                                                 ;;;
;;; ----------------------------------------------------------------------- ;;;

#|

This file is part of the BOOMS system:
+-----------------------------------------------------------------------------+
|                                                                             |
| /######   /#####   /#####  /##     /##  /#####                              |
| /##///## /##///## /##///## /###   /### /##///##                        /--- |
| /##  /## /##  /## /##  /## /#### /#### /##  ///          /------/     /     |
| /######/ /##  /## /##  /## /##/####/## //#####          /      /     /      |
| /##///## /##  /## /##  /## /##//##//##  /////##        /------/ __  /       |
| /##  /## /##  /## /##  /## /## /// /##      /##   __  /  __  / /  \/        |
| /##  /## /##  /## /##  /## /##     /## /##  /##  /  \/  /  \/  \__/         |
| /######/ //#####/ //#####/ /##     /## //#####/  \__/   \__/                |
| ///////   //////   //////  ///     ///  //////                              |
|                                                                             |
|                   Booms Object Oriented Music Structures.                   |
|Eli Barzilay:                                                   Maze is Life!|
+-----------------------------------------------------------------------------+

|#


;;;-------------------------------------------------------------------------;;;
;;;  C O N S T A N T  file                                                  ;;;
;;;-------------------------------------------------------------------------;;;

(in-package :booms-app)


;;;-------------------------------------------------------------------------;;;
;;;  S I Z E  defaults                                                      ;;;
;;;-------------------------------------------------------------------------;;;

;;; Icon sizes.
;;; Windows icon size.
(defconstant +WIN-ICON-SIZE+        32)
;;; Margin width around icon.
(defconstant +ICON-MARGIN+          4)
;;; Icon size.
(defconstant +ICON-SIZE+            (+ +win-icon-size+ (* 2 +icon-margin+)))
;;; Icon size divided by 2, used for centering icons.
(defconstant +ICON-SIZE/2+          (round +icon-size+ 2))

;;; Socket sizes.
;;; Size of a socket box.
(defconstant +SOCKET-SIZE+          8)
;;; Size of socket margin.
(defconstant +SOCKET-MARGIN+        4)
;;; Size of socket margin.
(defconstant +SOCKET-TOTAL-SIZE+    (+ +socket-size+ +socket-margin+))
;;; Distance of top socket from left edge of icon.
(defconstant +TOP-SIDE-MARGIN+      (- +icon-size/2+ (round +socket-size+ 2)))

;;; Line widths.
(defconstant +BORDER-LINE-WIDTH+    4)
(defconstant +HILIGHT-LINE-WIDTH+   2)

;;; Grid sizes.
(defconstant +GRID-MARGIN+          0)
(defconstant +GRID-SIZE-X+          (round (+ +icon-size+ +grid-margin+) 4))
(defconstant +GRID-SIZE-Y+          (round (+ +icon-size+
                                              +socket-total-size+
                                              +socket-total-size+
                                              +socket-margin+
                                              +grid-margin+)
                                           6))

;;; Margin for abstraction text.
(defconstant +ABSTRACT-TEXT-MARGIN+ 2)

;;; Margin for icon text.
(defconstant +ICON-TEXT-MARGIN+     6)

;;; Spacing between groups in toolbar.
(defconstant +TOOLBAR-SPACE+        5)
;;; Size of icon in toolbar.
(defconstant +TOOLBAR-BUTTON-SIZE+  26)
;;; Total height of the toolbar.
(defconstant +TOOLBAR-HEIGHT+       (+ +toolbar-button-size+
                                       (* 2 +toolbar-space+)))
;;; Icon class palette size.
(defconstant +PALETTE-SIZE-X+       140)
(defconstant +PALETTE-SIZE-Y+       500)

;;; Dragging threshold - wait this far brfore real dragging.
(defconstant +DRAG-THRESHOLD+       6)


;;;-------------------------------------------------------------------------;;;
;;;  C O L O R S  defaults                                                  ;;;
;;;-------------------------------------------------------------------------;;;

;;; Background color of application window.
(defconstant +BOOMS-BACK-COLOR+      #S(rgb red 0 green 0 blue 128))
;;; Background color of doc window.
(defconstant +DOC-BACK-COLOR+        white)

;;; Colors for icons.
(defconstant +ICON-BORDER-COLOR+     blue)
(defconstant +ICON-BG-COLOR+         light-gray)
(defconstant +ICON-SELECT-BG-COLOR+  #S(rgb red 255 green 192 blue 192))
(defconstant +ICON-TEXT-COLOR+       black)
(defconstant +ICON-TEXT-FG-COLOR+    blue)
(defconstant +ICON-TEXT-BG-COLOR+    yellow)

;;; Colors for sockets.
(defconstant +SOCKET-EMPTY-COLOR+    #S(rgb red 96 green 0 blue 0))
(defconstant +SOCKET-FULL-COLOR+     red)
(defconstant +SOCKET-CONSTANT-COLOR+ yellow)
(defconstant +SOCKET-HOLDER-COLOR+   blue)
(defconstant +SOCKET-TOP-COLOR+      green)

;;; Colors for abstraction text.
(defconstant +ABSTRACT-TEXT-FG+      yellow)
(defconstant +ABSTRACT-TEXT-BG+      #S(rgb red 0 green 0 blue 96))


;;;-------------------------------------------------------------------------;;;
;;;  F O N T  defaults                                                      ;;;
;;;-------------------------------------------------------------------------;;;

;;; Status-bar font.
(defconstant +STATUS-BAR-FONT+     (make-font :modern :arial 18 '(:bold)))

;;; Palette font.
(defconstant +PALETTE-FONT+        (make-font :swiss :arial 16 '()))

;;; Iconic-text-font.
(defconstant +ICON-TEXT-FONT+      (make-font :swiss :arial 24 '(:bold)))

;;; Icon temporary text font.
(defconstant +ICON-TEMP-TEXT-FONT+ (make-font :modern :courier\ new 24
                                              '(:bold)))

;;; Abstraction small text font.
(defconstant +ABSTRACT-TEXT-FONT+  (make-font :swiss :arial 11 '(:bold)))


;;;-------------------------------------------------------------------------;;;
;;;  M I S C  defaults                                                      ;;;
;;;-------------------------------------------------------------------------;;;

;;; This is the threshold of a full redraw - if there are more than these many
;;; redraw events compared to the icons number - then we go for a full redraw.
(defconstant +REDRAW-ALL-RATIO-THRESHOLD+ 0.6)

;;; The default initial volume value.
(defconstant +INITIAL-VOLUME+ 0.80)

;;; The default initial volume value.
(defconstant +INITIAL-TEMPO+ 0.50)


;;;-------------------------------------------------------------------------;;;
;;;  D O N E !                                                              ;;;
;;;-------------------------------------------------------------------------;;;

(provide :CONSTANT)

