
(format t "Loading ~a~%" *load-pathname*)

(in-package :cl-user)

(zoom-window top:*toploop-window* :maximized)
(set-foreground-color top:*toploop-window* yellow)
(set-background-color top:*toploop-window* #S(rgb blue 64))

(setq *load-verbose* nil)

;;(setf *methods-named* t)  ;; should remove this when done compiling

;;; Handle directories
(set-current-directory "C:\\ALLEGRO\\BOOMS")
(setf *default-pathname-defaults* #P"C:\\ALLEGRO\\BOOMS\\")
(setf *load-pathname-types* (list #p".fsl" #p".lsp"))

;;; Load editi for winemacs
;; (load "C:\\ALLEGRO\\EDITI\\EVAL-ACL.LSP")

;;; Commands handling - in the commands menu and button palette.
(defmacro DEFCOMMAND (command args &body body/parameters)
  (let ((body body/parameters)
        (parameter-setters nil))
    (while (keywordp (first body))
      (push `(get ',command ,(pop body)) parameter-setters)
      (push (pop body) parameter-setters))
    `(progn (defun ,command ,args ,@body)
            (setf ,@(nreverse parameter-setters))
            (add-menu-command    ',command)
            (add-palette-command ',command)
            ',command)))

(defparameter *SYSTEM-TITLE* nil)

(defparameter *COMMAND-MENU* nil)
(defun MAKE-COMMAND-MENU ()
  (or *command-menu*
      (setf *command-menu*
            (open-menu '() 'pull-down-menu *lisp-menu-bar* :title *system-title*
                       :selection-function 'funcall-menu-item))))
(defun ADD-MENU-COMMAND (command)
  (add-to-menu (make-command-menu)
               (make-menu-item :title (get command :title) :value command)
               :at-end t))

(defparameter *COMMAND-PALETTE* nil)
(defun MAKE-COMMAND-PALETTE ()
  (or *command-palette*
      (setf
       *command-palette*
       (open-dialog '() 'dialog *lisp-frame-window*
                    :title (remove #\~ *system-title*)
                    :window-border :palette
                    :window-state  :normal
                    :user-closable nil :user-moveable t :user-resizable nil
                    :user-scrollable nil :user-shrinkable nil :overlapped t
                    :pop-up-p nil
                    :window-interior (nbox-move (make-box 0 0 100 0)
                                                #.(make-position 920 200))))))
(defun ADD-PALETTE-COMMAND (command)
  (make-command-palette)
  (let ((y (window-interior-height *command-palette*)))
    (resize-window *command-palette*
                   (make-position
                    (window-interior-width *command-palette*) (+ y 30)))
    (add-widget (make-dialog-item
                 :widget       'button
                 :title        (get command :title)
                 :box          (make-box 4 (+ y 2) 96 (+ y 28))
                 :3d-border    t
                 :tabstop      t
                 :groupstart   nil
                 :set-value-fn #'(lambda (&rest r) (funcall command) nil))
                *command-palette*)))

(defun CLOSE-COMMANDS ()
  (when *command-menu*
    (close *command-menu*)
    (remove-from-menu
     *lisp-menu-bar*
     (remove-if-not #'(lambda (mi) (equalp (menu-item-title mi) *system-title*))
                    (menu-items *lisp-menu-bar*))))
  (when *command-palette*
    (close *command-palette*))
  (setf *command-menu* nil *command-palette* nil))


;;; Booms stuff

(setf *SYSTEM-TITLE* "B~OOMS")
(defcommand START-BOOMS ()
  :title "~Run"
  (if (find-package :booms-app)
    (funcall (symbol-function (find-symbol "BOOMS" :booms-app)))
    (load "_run")))
(defcommand LOAD-BOOMS ()
  :title "~Load"
  (load "_load"))
(defcommand LOAD-AND-RUNBOOMS ()
  :title "L~oad+Run"
  (load "_run"))
(defcommand COMPILE-BOOMS ()
  :title "~Compile"
  (load "_compile"))
(defcommand HIDE-ALLEGRO ()
  :title "~HideLisp"
  (shrink-window *lisp-frame-window* t))
(defcommand SHOW-ALLEGRO ()
  :title "~ShowLisp"
  (zoom-window *lisp-frame-window* :maximized))

;;(close-commands)


;;; If started from winemacs - iconize
(when (search "WINEMACS" *command-line*)
  (setf (stream-title *lisp-frame-window*) "Allegro Lisp [Emacs]")
  (shrink-window *lisp-frame-window* nil))

